#ifndef JPEGDECODER_H
#define JPEGDECODER_H

#include <QObject>
#include <QByteArray>
#include <QPoint>
#include <QSize>
#include <QImage>
#include <QDebug>

#include "concurrentqueue.h"

struct Jpeg {
    Jpeg(const QByteArray &d, const int i) :
        data(d), index(i)
    {
    }
    ~Jpeg()
    {
        // QByteArray::fromRawData: " QByteArray does not take ownership of data,
        // so the QByteArray destructor will never delete the raw data,
        // even when the last QByteArray referring to data is destroyed."
        delete[] data.constData();
    }

    QByteArray data;
    int index;
};

/*!
 * \brief Loads JPEG images
 *
 * Consumes
 */
class JpegDecoder : public QObject
{
    Q_OBJECT
public:
    JpegDecoder(ConcurrentQueue<Jpeg*, 64u> *queue, QObject *parent = 0);
    ConcurrentQueue<Jpeg*, 64u> *m_queue;
signals:
    void finished(const QImage &image, const int width, const int height, const int index);
public slots:
    void operate();
};

#endif // JPEGDECODER_H
